@@ -3,7 +3,7 @@ from typing import Generic, Optional, Type
 import attr
 
 from opyoid.frozen_target import FrozenTarget
-from opyoid.typings import InjectedT
+from opyoid.utils import InjectedT
 
 
 @attr.s(auto_attribs=True, frozen=True)
@@ -15,9 +15,9 @@ class Binding(Generic[InjectedT]):
         raise NotImplementedError
 
     @property
-    def annotation(self) -> Optional[str]:
+    def named(self) -> Optional[str]:
         raise NotImplementedError
 
     @property
     def target(self) -> FrozenTarget[InjectedT]:
-        return FrozenTarget(self.target_type, self.annotation)
+        return FrozenTarget(self.target_type, self.named)
