@@ -1,5 +1,5 @@
 from opyoid.provider import Provider
-from opyoid.typings import InjectedT
+from opyoid.utils import InjectedT
 from .singleton_scope import SingletonScope
 
 
